@@ -1,6 +1,6 @@
 # Built-in Module
 import re, random, sys, time
-from urllib.parse import urlparse
+from urllib.parse import urlparse, urljoin
 from urllib.request import urlopen
 from urllib.error import HTTPError
 from requests.exceptions import TooManyRedirects
@@ -72,7 +72,7 @@ def find_uri(url):
     # change "relative" uri into "absolute" one
     uris_misc = {urljoin(url, i) for i in uris_misc}
     # exclude mailto:// or javascript:// ...
-    uris_misc = {i for i in uri_misc if is_valid_scheme(i)}
+    uris_misc = {i for i in uris_misc if is_valid_scheme(i)}
     return remove_useless(uris_misc)
 
 
