@@ -23,6 +23,8 @@ Options:
     -r, --retry <times>         Set a retry limit on failed save.
     -t,  --only-target           Save just target webpage(s).
     -L, --recursive <level>     Set maximum recursion depth.
-    -p, --only-page             Get only URIs of type web page.
+    -p, --only-page             Get only URIs that are considered web pages.
+                                (Exclude URIs of images, videos, css, js ...)
+
 ''',end="")
 
